@@ -43,6 +43,8 @@ class Dns:
 
     def drop(self):
         self.domain_config.remove()
+        self.service_config.remove_all()
+        self.port_mapper.remove_all()
 
     def add_service(self, name, protocol, type, port, url=None):
         self.port_mapper.add(port)
